@@ -1,6 +1,23 @@
+# -*- coding: utf-8 -*-
+#
+#  This file is part of Sequana software
+#
+#  Copyright (c) 2016 - Sequana Development Team
+#
+#  File author(s):
+#      Thomas Cokelaer <thomas.cokelaer@pasteur.fr>
+#
+#  Distributed under the terms of the 3-clause BSD license.
+#  The full license is in the LICENSE file, distributed with this software.
+#
+#  website: https://github.com/sequana/sequana
+#  documentation: http://sequana.readthedocs.io
+#
+##############################################################################
 import sys
 import os
 import argparse
+import subprocess
 
 from sequana_pipetools.options import *
 from sequana_pipetools.misc import Colors
@@ -46,6 +63,10 @@ class Options(argparse.ArgumentParser):
                 iterative taxonomy is performed as explained in online sequana
                 documentation. You may mix kraken1 and kraken2 databases""")
 
+        self.add_argument("--run", default=False, action="store_true",
+            help="execute the pipeline directly")
+
+
     def parse_args(self, *args):
         args_list = list(*args)
         if "--from-project" in args_list:
@@ -93,12 +114,16 @@ def main(args=None):
 
         cfg['sequana_taxonomy']['level'] = options.kraken_level
         cfg['sequana_taxonomy']['databases'] = options.databases
+        for db in options.databases:
+            manager.exists(db)
         cfg['sequana_taxonomy']['confidence'] = options.kraken_confidence
 
     # finalise the command and save it; copy the snakemake. update the config
     # file and save it.
     manager.teardown()
 
+    if options.run:
+        subprocess.Popen(["sh", '{}.sh'.format(NAME)], cwd=options.workdir)
 
 if __name__ == "__main__":
     main()
